@@ -17,10 +17,13 @@ from .analysis import (
     visualize_histograms,
     visualize_scatter_matrix,
     visualize_image_classes,
-    assess_image_quality
+    assess_image_quality,
+    analyze_image_features,
+    analyze_encoding_needs,
+    apply_smart_encoding
 )
 
-__version__ = "0.10.0"
+__version__ = "0.12.7"
 __author__ = "Evan Low"
 __email__ = "evan.low@illumetechnology.com"
 
@@ -56,5 +59,8 @@ __all__ = [
     'visualize_histograms',
     'visualize_scatter_matrix',
     'visualize_image_classes',
-    'assess_image_quality'
+    'assess_image_quality',
+    'analyze_image_features',
+    'analyze_encoding_needs',
+    'apply_smart_encoding'
 ]
