@@ -19,7 +19,10 @@ from .core import (
     visualize_histograms,
     visualize_scatter_matrix,
     visualize_image_classes,
-    assess_image_quality
+    assess_image_quality,
+    analyze_image_features,
+    analyze_encoding_needs,
+    apply_smart_encoding
 )
 
 __all__ = [
@@ -37,5 +40,8 @@ __all__ = [
     'visualize_histograms',
     'visualize_scatter_matrix',
     'visualize_image_classes',
-    'assess_image_quality'
+    'assess_image_quality',
+    'analyze_image_features',
+    'analyze_encoding_needs',
+    'apply_smart_encoding'
 ]
